@@ -24,7 +24,6 @@
 -- catalog tables
 --
 
-
 CREATE TABLE ag_graph (
   graphid oid NOT NULL,
   name name NOT NULL,
@@ -48,7 +47,6 @@ CREATE DOMAIN label_id AS int NOT NULL CHECK (VALUE > 0 AND VALUE <= 65535);
 CREATE DOMAIN label_kind AS "char" NOT NULL CHECK (VALUE = 'v' OR VALUE = 'e');
 
 CREATE TABLE ag_label (
-
   name name NOT NULL,
   graph oid NOT NULL,
   id label_id,
@@ -56,8 +54,8 @@ CREATE TABLE ag_label (
   relation regclass NOT NULL,
   seq_name name NOT NULL,
   CONSTRAINT fk_graph_oid
-    FOREIGN KEY(graph)
-    REFERENCES ag_graph(graphid)
+  FOREIGN KEY(graph)
+  REFERENCES ag_graph(graphid)
 );
 
 -- include content of the ag_label table into the pg_dump output
@@ -76,6 +74,7 @@ CREATE UNIQUE INDEX ag_label_relation_index ON ag_label USING btree (relation);
 CREATE UNIQUE INDEX ag_label_seq_name_graph_index
 ON ag_label
 USING btree (seq_name, graph);
+
 --
 -- catalog lookup functions
 --
@@ -111,21 +110,22 @@ CREATE FUNCTION ag_catalog.create_elabel(graph_name name, label_name name)
     LANGUAGE c
 AS 'MODULE_PATHNAME';
 
-CREATE FUNCTION ag_catalog.alter_graph(graph_name name, operation cstring, new_value name)
+CREATE FUNCTION ag_catalog.alter_graph(graph_name name, operation cstring,
+                                       new_value name)
 RETURNS void
 LANGUAGE c
 AS 'MODULE_PATHNAME';
 
 CREATE FUNCTION ag_catalog.drop_label(graph_name name, label_name name,
-                           force boolean = false)
+                                      force boolean = false)
 RETURNS void
 LANGUAGE c
 AS 'MODULE_PATHNAME';
 
 CREATE FUNCTION ag_catalog.load_labels_from_file(graph_name name,
-                                            label_name name,
-                                            file_path text,
-                                            id_field_exists bool default true)
+                                                 label_name name,
+                                                 file_path text,
+                                                 id_field_exists bool default true)
     RETURNS void
     LANGUAGE c
     AS 'MODULE_PATHNAME';
@@ -365,7 +365,7 @@ AS 'MODULE_PATHNAME';
 CREATE FUNCTION ag_catalog._label_name(graph_oid oid, graphid)
 RETURNS cstring
 LANGUAGE c
-STABLE
+IMMUTABLE
 PARALLEL SAFE
 AS 'MODULE_PATHNAME';
 
@@ -1391,7 +1391,6 @@ CREATE OPERATOR ^ (
   RIGHTARG = agtype
 );
 
-
 CREATE FUNCTION ag_catalog.graphid_hash_cmp(graphid)
 RETURNS INTEGER
 LANGUAGE c
@@ -3088,7 +3087,6 @@ CREATE CAST (agtype AS graphid)
 WITH FUNCTION ag_catalog.agtype_to_graphid(agtype)
 AS IMPLICIT;
 
-
 --
 -- agtype - path
 --
@@ -3106,7 +3104,7 @@ AS 'MODULE_PATHNAME';
 CREATE FUNCTION ag_catalog._agtype_build_vertex(graphid, cstring, agtype)
 RETURNS agtype
 LANGUAGE c
-STABLE
+IMMUTABLE
 CALLED ON NULL INPUT
 PARALLEL SAFE
 AS 'MODULE_PATHNAME';
@@ -3114,10 +3112,11 @@ AS 'MODULE_PATHNAME';
 --
 -- agtype - edge
 --
-CREATE FUNCTION ag_catalog._agtype_build_edge(graphid, graphid, graphid, cstring, agtype)
+CREATE FUNCTION ag_catalog._agtype_build_edge(graphid, graphid, graphid,
+                                              cstring, agtype)
 RETURNS agtype
 LANGUAGE c
-STABLE
+IMMUTABLE
 CALLED ON NULL INPUT
 PARALLEL SAFE
 AS 'MODULE_PATHNAME';
@@ -3162,15 +3161,14 @@ AS 'MODULE_PATHNAME';
 -- functions we need. Wrap the function with this to
 -- prevent that from happening
 --
-CREATE FUNCTION ag_catalog.agtype_volatile_wrapper(agt agtype)
-RETURNS agtype AS $return_value$
-BEGIN
-	RETURN agt;
-END;
-$return_value$ LANGUAGE plpgsql
+
+CREATE FUNCTION ag_catalog.agtype_volatile_wrapper("any")
+RETURNS agtype
+LANGUAGE c
 VOLATILE
 CALLED ON NULL INPUT
-PARALLEL SAFE;
+PARALLEL SAFE
+AS 'MODULE_PATHNAME';
 
 --
 -- agtype - list literal (`[expr, ...]`)
@@ -3428,6 +3426,7 @@ AS 'MODULE_PATHNAME';
 --
 -- Scalar Functions
 --
+
 CREATE FUNCTION ag_catalog.age_id(agtype)
 RETURNS agtype
 LANGUAGE c
@@ -3508,6 +3507,14 @@ RETURNS NULL ON NULL INPUT
 PARALLEL SAFE
 AS 'MODULE_PATHNAME';
 
+CREATE FUNCTION ag_catalog.age_tobooleanlist(variadic "any")
+RETURNS agtype
+LANGUAGE c
+IMMUTABLE
+RETURNS NULL ON NULL INPUT
+PARALLEL SAFE
+AS 'MODULE_PATHNAME';
+
 CREATE FUNCTION ag_catalog.age_tofloat(variadic "any")
 RETURNS agtype
 LANGUAGE c
@@ -3516,6 +3523,14 @@ RETURNS NULL ON NULL INPUT
 PARALLEL SAFE
 AS 'MODULE_PATHNAME';
 
+CREATE FUNCTION ag_catalog.age_tofloatlist(variadic "any")
+RETURNS agtype
+LANGUAGE c
+IMMUTABLE
+RETURNS NULL ON NULL INPUT
+PARALLEL SAFE
+AS 'MODULE_PATHNAME';
+
 CREATE FUNCTION ag_catalog.age_tointeger(variadic "any")
 RETURNS agtype
 LANGUAGE c
@@ -3524,6 +3539,14 @@ RETURNS NULL ON NULL INPUT
 PARALLEL SAFE
 AS 'MODULE_PATHNAME';
 
+CREATE FUNCTION ag_catalog.age_tointegerlist(variadic "any")
+RETURNS agtype
+LANGUAGE c
+IMMUTABLE
+RETURNS NULL ON NULL INPUT
+PARALLEL SAFE
+AS 'MODULE_PATHNAME';
+
 CREATE FUNCTION ag_catalog.age_tostring(variadic "any")
 RETURNS agtype
 LANGUAGE c
@@ -3532,6 +3555,14 @@ RETURNS NULL ON NULL INPUT
 PARALLEL SAFE
 AS 'MODULE_PATHNAME';
 
+CREATE FUNCTION ag_catalog.age_tostringlist(variadic "any")
+RETURNS agtype
+LANGUAGE c
+IMMUTABLE
+RETURNS NULL ON NULL INPUT
+PARALLEL SAFE
+AS 'MODULE_PATHNAME';
+
 CREATE FUNCTION ag_catalog.age_size(variadic "any")
 RETURNS agtype
 LANGUAGE c
@@ -3786,6 +3817,19 @@ IMMUTABLE
 PARALLEL SAFE
 AS 'MODULE_PATHNAME';
 
+CREATE FUNCTION ag_catalog.age_pi()
+RETURNS agtype
+LANGUAGE c
+IMMUTABLE
+PARALLEL SAFE
+AS 'MODULE_PATHNAME';
+
+CREATE FUNCTION ag_catalog.age_rand()
+RETURNS agtype
+LANGUAGE c
+PARALLEL SAFE
+AS 'MODULE_PATHNAME';
+
 CREATE FUNCTION ag_catalog.age_exp(variadic "any")
 RETURNS agtype
 LANGUAGE c
@@ -4031,6 +4075,13 @@ IMMUTABLE
 PARALLEL SAFE
 AS 'MODULE_PATHNAME';
 
+CREATE FUNCTION ag_catalog.agtype_typecast_bool(variadic "any")
+RETURNS agtype
+LANGUAGE c
+IMMUTABLE
+PARALLEL SAFE
+AS 'MODULE_PATHNAME';
+
 CREATE FUNCTION ag_catalog.agtype_typecast_vertex(variadic "any")
 RETURNS agtype
 LANGUAGE c
@@ -4092,7 +4143,6 @@ CALLED ON NULL INPUT
 PARALLEL SAFE
 AS 'MODULE_PATHNAME';
 
-
 -- function to create an AGTV_PATH from a VLE_path_container
 CREATE FUNCTION ag_catalog.age_materialize_vle_path(agtype)
 RETURNS agtype
@@ -4119,7 +4169,6 @@ RETURNS NULL ON NULL INPUT
 PARALLEL SAFE
 AS 'MODULE_PATHNAME';
 
-
 CREATE FUNCTION ag_catalog.age_match_two_vle_edges(agtype, agtype)
 RETURNS boolean
 LANGUAGE C
@@ -4187,20 +4236,22 @@ STABLE
 PARALLEL SAFE
 AS 'MODULE_PATHNAME';
 
-CREATE FUNCTION ag_catalog.create_complete_graph(graph_name name, nodes int, edge_label name, node_label name = NULL)
+CREATE FUNCTION ag_catalog.create_complete_graph(graph_name name, nodes int,
+                                                 edge_label name,
+                                                 node_label name = NULL)
 RETURNS void
 LANGUAGE c
 CALLED ON NULL INPUT
 PARALLEL SAFE
 AS 'MODULE_PATHNAME';
 
-CREATE FUNCTION ag_catalog.age_create_barbell_graph(graph_name name, 
-                                                graph_size int, 
-                                                bridge_size int,
-                                                node_label name = NULL,
-                                                node_properties agtype = NULL,
-                                                edge_label name = NULL,
-                                                edge_properties agtype = NULL)
+CREATE FUNCTION ag_catalog.age_create_barbell_graph(graph_name name,
+                                                    graph_size int,
+                                                    bridge_size int,
+                                                    node_label name = NULL,
+                                                    node_properties agtype = NULL,
+                                                    edge_label name = NULL,
+                                                    edge_properties agtype = NULL)
 RETURNS void
 LANGUAGE c
 CALLED ON NULL INPUT
