@@ -25,6 +25,7 @@
 -- Load extension and set path
 --
 LOAD 'age';
+SET extra_float_digits = 0;
 SET search_path TO ag_catalog;
 
 --
@@ -403,7 +404,7 @@ SELECT agtype_in('{"bool":true, "null": null}') = agtype_in('{"null":null, "bool
 SELECT agtype_in('{"bool":true}') < agtype_in('{"bool":true, "null": null}');
 
 -- Comparisons between types
--- Object < List < String < Boolean < Integer = Float = Numeric < Null
+-- Path < Edge < Vertex < Object < List < String < Boolean < Integer = Float = Numeric < Null
 SELECT agtype_in('1') < agtype_in('null');
 SELECT agtype_in('NaN') < agtype_in('null');
 SELECT agtype_in('Infinity') < agtype_in('null');
@@ -415,8 +416,17 @@ SELECT agtype_in('[1,3,5,7,9,11]') < agtype_in('"string"');
 SELECT agtype_in('{"bool":true, "integer":1}') < agtype_in('[1,3,5,7,9,11]');
 SELECT agtype_in('[1, "string"]') < agtype_in('[1, 1]');
 SELECT agtype_in('{"bool":true, "integer":1}') < agtype_in('{"bool":true, "integer":null}');
+SELECT agtype_in('{"id":0, "label": "v", "properties":{"i":0}}::vertex') < agtype_in('{"bool":true, "i":0}');
+SELECT agtype_in('{"id":2, "start_id":0, "end_id":1, "label": "e", "properties":{"i":0}}::edge') < agtype_in('{"id":0, "label": "v", "properties":{"i":0}}::vertex');
+SELECT agtype_in('[{"id": 0, "label": "v", "properties": {"i": 0}}::vertex, {"id": 2, "start_id": 0, "end_id": 1, "label": "e", "properties": {"i": 0}}::edge, {"id": 1, "label": "v", "properties": {"i": 0}}::vertex]::path') < agtype_in('{"id":2, "start_id":0, "end_id":1, "label": "e", "properties":{"i":0}}::edge');
 SELECT agtype_in('1::numeric') < agtype_in('null');
 SELECT agtype_in('true') < agtype_in('1::numeric');
+-- Testing orderability between types
+SELECT * FROM create_graph('orderability_graph');
+SELECT * FROM cypher('orderability_graph', $$ CREATE (:vertex {prop: null}), (:vertex {prop: 1}), (:vertex {prop: 1.01}),(:vertex {prop: true}), (:vertex {prop:"string"}),(:vertex {prop:"string_2"}), (:vertex {prop:[1, 2, 3]}), (:vertex {prop:[1, 2, 3, 4, 5]}), (:vertex {prop:{bool:true, i:0}}), (:vertex {prop:{bool:true, i:null}}), (:vertex {prop: {id:0, label: "v", properties:{i:0}}::vertex}),  (:vertex {prop: {id: 2, start_id: 0, end_id: 1, label: "e", properties: {i: 0}}::edge}), (:vertex {prop: [{id: 0, label: "v", properties: {i: 0}}::vertex, {id: 2, start_id: 0, end_id: 1, label: "e", properties: {i: 0}}::edge, {id: 1, label: "v", properties: {i: 0}}::vertex]::path}) $$)  AS (x agtype);
+SELECT * FROM cypher('orderability_graph', $$ MATCH (n) RETURN n ORDER BY n.prop $$) AS (sorted agtype);
+SELECT * FROM cypher('orderability_graph', $$ MATCH (n) RETURN n ORDER BY n.prop DESC $$) AS (sorted agtype);
+SELECT * FROM drop_graph('orderability_graph', true);
 
 --
 -- Test overloaded agytype any comparison operators =, <>, <, >, <=, >=,
@@ -524,8 +534,8 @@ SELECT agtype_in('true') < '1::numeric';
 SELECT agtype_to_bool(agtype_in('true'));
 SELECT agtype_to_bool(agtype_in('false'));
 -- These should all fail
-SELECT agtype_to_bool(agtype_in('null'));
 SELECT agtype_to_bool(agtype_in('1'));
+SELECT agtype_to_bool(agtype_in('null'));
 SELECT agtype_to_bool(agtype_in('1.0'));
 SELECT agtype_to_bool(agtype_in('"string"'));
 SELECT agtype_to_bool(agtype_in('[1,2,3]'));
@@ -540,6 +550,30 @@ SELECT bool_to_agtype(null);
 SELECT bool_to_agtype(true) = bool_to_agtype(true);
 SELECT bool_to_agtype(true) <> bool_to_agtype(false);
 
+--
+-- Test boolean to pg_bigint cast
+--
+SELECT agtype_to_int8(agtype_in('true'));
+SELECT agtype_to_int8(agtype_in('false'));
+
+--
+-- Test boolean to integer cast
+--
+SELECT agtype_to_int4(agtype_in('true'));
+SELECT agtype_to_int4(agtype_in('false'));
+SELECT agtype_to_int4(agtype_in('null'));
+
+--
+-- Test agtype to integer cast
+--
+SELECT agtype_to_int4(agtype_in('1'));
+SELECT agtype_to_int4(agtype_in('1.45'));
+SELECT agtype_to_int4(agtype_in('1.444::numeric'));
+-- These should all fail
+SELECT agtype_to_int4(agtype_in('"string"'));
+SELECT agtype_to_int4(agtype_in('[1, 2, 3]'));
+SELECT agtype_to_int4(agtype_in('{"int":1}'));
+
 --
 -- Test agtype to int[]
 --
