@@ -209,7 +209,7 @@ static void rescan_cypher_delete(CustomScanState *node)
 {
      ereport(ERROR,
              (errcode(ERRCODE_FEATURE_NOT_SUPPORTED),
-                      errmsg("cypher DELETE clause cannot be rescaned"),
+                      errmsg("cypher DELETE clause cannot be rescanned"),
                       errhint("its unsafe to use joins in a query with a Cypher DELETE clause")));
 }
 
@@ -279,7 +279,7 @@ static agtype_value *extract_entity(CustomScanState *node,
 static void delete_entity(EState *estate, ResultRelInfo *resultRelInfo,
                           HeapTuple tuple)
 {
-    ResultRelInfo *saved_resultRelInfo;
+    ResultRelInfo **saved_resultRels;
     LockTupleMode lockmode;
     TM_FailureData hufd;
     TM_Result lock_result;
@@ -287,8 +287,8 @@ static void delete_entity(EState *estate, ResultRelInfo *resultRelInfo,
     Buffer buffer;
 
     // Find the physical tuple, this variable is coming from
-    saved_resultRelInfo = estate->es_result_relation_info;
-    estate->es_result_relation_info = resultRelInfo;
+    saved_resultRels = estate->es_result_relations;
+    estate->es_result_relations = &resultRelInfo;
 
     lockmode = ExecUpdateLockMode(estate, resultRelInfo);
 
@@ -352,7 +352,7 @@ static void delete_entity(EState *estate, ResultRelInfo *resultRelInfo,
 
     ReleaseBuffer(buffer);
 
-    estate->es_result_relation_info = saved_resultRelInfo;
+    estate->es_result_relations = saved_resultRels;
 }
 
 /*
@@ -483,7 +483,7 @@ static void find_connected_edges(CustomScanState *node, char *graph_name,
      * any edges attached to it.
      *
      * XXX: If we implement an on-disc graph storage system. Such as
-     * an adjacency matrix, the performace of this check can be massively
+     * an adjacency matrix, the performance of this check can be massively
      * improved. However, right now we have to scan every edge to see if
      * one has this vertex as a start or end vertex.
      */
