@@ -49,7 +49,6 @@
 #include "commands/label_commands.h"
 #include "nodes/cypher_nodes.h"
 #include "parser/cypher_expr.h"
-#include "parser/cypher_item.h"
 #include "parser/cypher_parse_node.h"
 #include "parser/cypher_transform_entity.h"
 #include "utils/ag_func.h"
@@ -64,6 +63,7 @@
 #define FUNC_AGTYPE_TYPECAST_INT "agtype_typecast_int"
 #define FUNC_AGTYPE_TYPECAST_PG_FLOAT8 "agtype_to_float8"
 #define FUNC_AGTYPE_TYPECAST_PG_BIGINT "agtype_to_int8"
+#define FUNC_AGTYPE_TYPECAST_BOOL "agtype_typecast_bool"
 
 static Node *transform_cypher_expr_recurse(cypher_parsestate *cpstate,
                                            Node *expr);
@@ -93,8 +93,8 @@ static Node *transform_CoalesceExpr(cypher_parsestate *cpstate,
                                     CoalesceExpr *cexpr);
 static Node *transform_SubLink(cypher_parsestate *cpstate, SubLink *sublink);
 static Node *transform_FuncCall(cypher_parsestate *cpstate, FuncCall *fn);
-static Node *transform_WholeRowRef(ParseState *pstate, ParseNamespaceItem *pnsi,
-                                   int location, int sublevels_up);
+static Node *transform_WholeRowRef(ParseState *pstate, RangeTblEntry *rte,
+                                   int location);
 static ArrayExpr *make_agtype_array_expr(List *args);
 
 /* transform a cypher expression */
@@ -148,19 +148,21 @@ static Node *transform_cypher_expr_recurse(cypher_parsestate *cpstate,
             ereport(ERROR, (errmsg_internal("unrecognized A_Expr kind: %d",
                                             a->kind)));
         }
-        break;
     }
     case T_BoolExpr:
         return transform_BoolExpr(cpstate, (BoolExpr *)expr);
     case T_NullTest:
     {
         NullTest *n = (NullTest *)expr;
+        NullTest *transformed_expr = makeNode(NullTest);
 
-        n->arg = (Expr *)transform_cypher_expr_recurse(cpstate,
-                                                       (Node *)n->arg);
-        n->argisrow = type_is_rowtype(exprType((Node *)n->arg));
+        transformed_expr->arg = (Expr *)transform_cypher_expr_recurse(cpstate,
+                                                         (Node *)n->arg);
+        transformed_expr->nulltesttype = n->nulltesttype;
+        transformed_expr->argisrow = type_is_rowtype(exprType((Node *)transformed_expr->arg));
+        transformed_expr->location = n->location;
 
-        return expr;
+        return (Node *) transformed_expr;
     }
     case T_CaseExpr:
         return transform_CaseExpr(cpstate, (CaseExpr *) expr);
@@ -258,18 +260,15 @@ static Node *transform_A_Const(cypher_parsestate *cpstate, A_Const *ac)
  * Private function borrowed from PG's transformWholeRowRef.
  * Construct a whole-row reference to represent the notation "relation.*".
  */
-static Node *transform_WholeRowRef(ParseState *pstate, ParseNamespaceItem *pnsi,
-                                   int location, int sublevels_up)
+static Node *transform_WholeRowRef(ParseState *pstate, RangeTblEntry *rte,
+                                   int location)
 {
     Var *result;
     int vnum;
-    RangeTblEntry *rte;
-
-    Assert(pnsi->p_rte != NULL);
-    rte = pnsi->p_rte;
+    int sublevels_up;
 
     /* Find the RTE's rangetable location */
-    vnum = pnsi->p_rtindex;
+    vnum = RTERangeTablePosn(pstate, rte, &sublevels_up);
 
     /*
      * Build the appropriate referencing node.  Note that if the RTE is a
@@ -279,7 +278,7 @@ static Node *transform_WholeRowRef(ParseState *pstate, ParseNamespaceItem *pnsi,
      * historically.  One argument for it is that "rel" and "rel.*" mean the
      * same thing for composite relations, so why not for scalar functions...
      */
-     result = makeWholeRowVar(rte, vnum, sublevels_up, true); 
+     result = makeWholeRowVar(rte, vnum, sublevels_up, true);
 
      /* location is not filled in by makeWholeRowVar */
      result->location = location;
@@ -297,6 +296,7 @@ static Node *transform_WholeRowRef(ParseState *pstate, ParseNamespaceItem *pnsi,
 static Node *transform_ColumnRef(cypher_parsestate *cpstate, ColumnRef *cref)
 {
     ParseState *pstate = (ParseState *)cpstate;
+    RangeTblEntry *rte = NULL;
     Node *field1 = NULL;
     Node *field2 = NULL;
     char *colname = NULL;
@@ -304,7 +304,6 @@ static Node *transform_ColumnRef(cypher_parsestate *cpstate, ColumnRef *cref)
     char *relname = NULL;
     Node *node = NULL;
     int levels_up;
-    ParseNamespaceItem *pnsi;
 
     switch (list_length(cref->fields))
     {
@@ -346,12 +345,11 @@ static Node *transform_ColumnRef(cypher_parsestate *cpstate, ColumnRef *cref)
                  * PostQUEL-inspired syntax.  The preferred form now is
                  * "rel.*".
                  */
-                pnsi = refnameNamespaceItem(pstate, NULL, colname,
+                rte = refnameRangeTblEntry(pstate, NULL, colname,
                                            cref->location, &levels_up);
-                if (pnsi)
+                if (rte)
                 {
-                    node = transform_WholeRowRef(pstate, pnsi, cref->location,
-                                                 levels_up);
+                    node = transform_WholeRowRef(pstate, rte, cref->location);
                 }
                 else
                 {
@@ -387,10 +385,9 @@ static Node *transform_ColumnRef(cypher_parsestate *cpstate, ColumnRef *cref)
                 }
 
                 /* locate the referenced RTE */
-                pnsi = refnameNamespaceItem(pstate, nspname, relname,
+                rte = refnameRangeTblEntry(pstate, nspname, relname,
                                            cref->location, &levels_up);
-
-                if (pnsi == NULL)
+                if (rte == NULL)
                 {
                     ereport(ERROR,
                             (errcode(ERRCODE_UNDEFINED_COLUMN),
@@ -406,15 +403,15 @@ static Node *transform_ColumnRef(cypher_parsestate *cpstate, ColumnRef *cref)
                  */
                 if (IsA(field2, A_Star))
                 {
-                    node = transform_WholeRowRef(pstate, pnsi, cref->location, levels_up);
+                    node = transform_WholeRowRef(pstate, rte, cref->location);
                     break;
                 }
 
                 Assert(IsA(field2, String));
 
                 /* try to identify as a column of the RTE */
-                node = scanNSItemForColumn(pstate, pnsi, 0, colname, cref->location);
-
+                node = scanRTEForColumn(pstate, rte, colname, cref->location, 0,
+                                        NULL);
                 if (node == NULL)
                 {
                     ereport(ERROR,
@@ -623,9 +620,9 @@ static Node *transform_cypher_map(cypher_parsestate *cpstate, cypher_map *cm)
         Const *newkey;
 
         key = lfirst(le);
-        le = lnext(cm->keyvals, le);
+        le = lnext(le);
         val = lfirst(le);
-        le = lnext(cm->keyvals, le);
+        le = lnext(le);
 
         newval = transform_cypher_expr_recurse(cpstate, val);
 
@@ -659,35 +656,108 @@ static Node *transform_cypher_map(cypher_parsestate *cpstate, cypher_map *cm)
     return (Node *)fexpr;
 }
 
+/*
+ * Helper function to transform a cypher list into an agtype list. The function
+ * will use agtype_add to concatenate lists when the number of parameters
+ * exceeds 100, a PG limitation.
+ */
 static Node *transform_cypher_list(cypher_parsestate *cpstate, cypher_list *cl)
 {
-    List *newelems = NIL;
-    ListCell *le;
-    FuncExpr *fexpr;
-    Oid func_oid;
+    List *abl_args = NIL;
+    ListCell *le = NULL;
+    FuncExpr *aa_lhs_arg = NULL;
+    FuncExpr *fexpr = NULL;
+    Oid abl_func_oid = InvalidOid;
+    Oid aa_func_oid = InvalidOid;
+    int nelems = 0;
+    int i = 0;
 
-    foreach (le, cl->elems)
+    /* determine which build function we need */
+    nelems = list_length(cl->elems);
+    if (nelems == 0)
     {
-        Node *newv;
-
-        newv = transform_cypher_expr_recurse(cpstate, lfirst(le));
-
-        newelems = lappend(newelems, newv);
-    }
-
-    if (list_length(newelems) == 0)
-    {
-        func_oid = get_ag_func_oid("agtype_build_list", 0);
+        abl_func_oid = get_ag_func_oid("agtype_build_list", 0);
     }
     else
     {
-        func_oid = get_ag_func_oid("agtype_build_list", 1, ANYOID);
+        abl_func_oid = get_ag_func_oid("agtype_build_list", 1, ANYOID);
     }
 
-    fexpr = makeFuncExpr(func_oid, AGTYPEOID, newelems, InvalidOid, InvalidOid,
-                         COERCE_EXPLICIT_CALL);
+    /* get the concat function oid, if necessary */
+    if (nelems > 100)
+    {
+        aa_func_oid = get_ag_func_oid("agtype_add", 2, AGTYPEOID, AGTYPEOID);
+    }
+
+    /* iterate through the list of elements */
+    foreach (le, cl->elems)
+    {
+        Node *texpr = NULL;
+
+        /* transform the argument */
+        texpr = transform_cypher_expr_recurse(cpstate, lfirst(le));
+
+        /*
+         * If we have more than 100 elements we will need to add in the list
+         * concatenation function.
+         */
+        if (i >= 100)
+        {
+            /* build the list function node argument for concatenate */
+            fexpr = makeFuncExpr(abl_func_oid, AGTYPEOID, abl_args, InvalidOid,
+                                 InvalidOid, COERCE_EXPLICIT_CALL);
+            fexpr->location = cl->location;
+
+            /* initial case, set up for concatenating 2 lists */
+            if (aa_lhs_arg == NULL)
+            {
+                aa_lhs_arg = fexpr;
+            }
+            /*
+             * For every other case, concatenate the list on to the previous
+             * concatenate operation.
+             */
+            else
+            {
+                List *aa_args = list_make2(aa_lhs_arg, fexpr);
+
+                fexpr = makeFuncExpr(aa_func_oid, AGTYPEOID, aa_args,
+                                     InvalidOid, InvalidOid,
+                                     COERCE_EXPLICIT_CALL);
+                fexpr->location = cl->location;
+
+                /* set the lhs to the concatenation operation */
+                aa_lhs_arg = fexpr;
+            }
+
+            /* reset */
+            abl_args = NIL;
+            i = 0;
+            fexpr = NULL;
+        }
+
+        /* now add the latest transformed expression to the list */
+        abl_args = lappend(abl_args, texpr);
+        i++;
+    }
+
+    /* now build the final list function */
+    fexpr = makeFuncExpr(abl_func_oid, AGTYPEOID, abl_args, InvalidOid,
+                         InvalidOid, COERCE_EXPLICIT_CALL);
     fexpr->location = cl->location;
 
+    /*
+     * If there was a previous concatenation or list function, build a final
+     * concatenation function node
+     */
+    if (aa_lhs_arg != NULL)
+    {
+        List *aa_args = list_make2(aa_lhs_arg, fexpr);
+
+        fexpr = makeFuncExpr(aa_func_oid, AGTYPEOID, aa_args, InvalidOid,
+                             InvalidOid, COERCE_EXPLICIT_CALL);
+    }
+
     return (Node *)fexpr;
 }
 
@@ -960,6 +1030,11 @@ static Node *transform_cypher_typecast(cypher_parsestate *cpstate,
     {
         fname = lappend(fname, makeString(FUNC_AGTYPE_TYPECAST_PG_BIGINT));
     }
+    else if ((pg_strcasecmp(ctypecast->typecast, "bool") == 0 || 
+             pg_strcasecmp(ctypecast->typecast, "boolean") == 0))
+    {
+        fname = lappend(fname, makeString(FUNC_AGTYPE_TYPECAST_BOOL));
+    }
     /* if none was found, error out */
     else
     {
@@ -1124,7 +1199,7 @@ static Node *transform_CoalesceExpr(cypher_parsestate *cpstate, CoalesceExpr
 /*
  * Code borrowed from PG's transformCaseExpr and updated for AGE
  */
-static Node *transform_CaseExpr(cypher_parsestate *cpstate,CaseExpr
+static Node *transform_CaseExpr(cypher_parsestate *cpstate, CaseExpr
                                 *cexpr)
 {
     ParseState *pstate = &cpstate->pstate;
@@ -1209,7 +1284,20 @@ static Node *transform_CaseExpr(cypher_parsestate *cpstate,CaseExpr
 
     resultexprs = lcons(newcexpr->defresult, resultexprs);
 
-    ptype = select_common_type(pstate, resultexprs, "CASE", NULL);
+    /*
+     * we pass a NULL context to select_common_type because the common types can
+     * only be AGTYPEOID or BOOLOID. If it returns invalidoid, we know there is a
+     * boolean involved.
+     */
+    ptype = select_common_type(pstate, resultexprs, NULL, NULL);
+
+    //InvalidOid shows that there is a boolean in the result expr.
+    if (ptype == InvalidOid)
+    {
+        //we manually set the type to boolean here to handle the bool casting.
+        ptype = BOOLOID;
+    }
+
     Assert(OidIsValid(ptype));
     newcexpr->casetype = ptype;
     /* casecollid will be set by parse_collate.c */
