@@ -77,6 +77,9 @@ int cypher_yylex(YYSTYPE *lvalp, YYLTYPE *llocp, ag_scanner_t scanner)
              * case sensitivity
              */
             lvalp->keyword = GetScanKeyword(kwnum, &CypherKeyword);
+            ident = pstrdup(token.value.s);
+            truncate_identifier(ident, strlen(ident), true);
+            lvalp->string = ident;
             *llocp = token.location;
             return CypherKeywordTokens[kwnum];
         }
@@ -143,7 +146,7 @@ List *parse_cypher(const char *s)
         return NIL;
 
     /*
-     * Append the extra node node regardless of its value. Currently the extra
+     * Append the extra node regardless of its value. Currently the extra
      * node is only used by EXPLAIN
     */
     return lappend(extra.result, extra.extra);
