@@ -31,8 +31,8 @@
 #ifndef AG_AGTYPE_H
 #define AG_AGTYPE_H
 
-#include "access/htup_details.h"
 #include "fmgr.h"
+#include "access/htup_details.h"
 #include "lib/stringinfo.h"
 #include "nodes/pg_list.h"
 #include "utils/array.h"
@@ -40,7 +40,6 @@
 #include "utils/syscache.h"
 
 #include "catalog/ag_namespace.h"
-#include "catalog/pg_type.h"
 #include "utils/graphid.h"
 
 /* Tokens used when sequentially processing an agtype value */
@@ -547,6 +546,9 @@ agtype_value *string_to_agtype_value(char *s);
 agtype_value *integer_to_agtype_value(int64 int_value);
 void add_agtype(Datum val, bool is_null, agtype_in_state *result, Oid val_type,
                 bool key_scalar);
+void pfree_agtype_value(agtype_value* value);
+void pfree_agtype_value_content(agtype_value* value);
+void pfree_agtype_in_state(agtype_in_state* value);
 
 /* Oid accessors for AGTYPE */
 Oid get_AGTYPEOID(void);
